<?php

class CommerceStoreEntityAPIController extends EntityAPIController {
  /**
   * Overrides EntityAPIController::delete().
   * We're doing this because EntityAPIController calls hook_entity_delete() after the entity is actually deleted,
   * although core calls them before entity is removed from the database.
   * See https://www.drupal.org/project/entity/issues/1789494 for more information.
   * This can be deleted if/when the issue above is fixed.
   *
   * @param $transaction
   *   Optionally a DatabaseTransaction object to use. Allows overrides to pass
   *   in their transaction object.
   */
  public function delete($ids, DatabaseTransaction $transaction = NULL) {
    $entities = $ids ? $this->load($ids) : FALSE;
    if (!$entities) {
      // Do nothing, in case invalid or no ids have been passed.
      return;
    }
    $transaction = isset($transaction) ? $transaction : db_transaction();

    try {
      $ids = array_keys($entities);
      foreach ($entities as $id => $entity) {
        $this->invoke('delete', $entity);
      }

      db_delete($this->entityInfo['base table'])
        ->condition($this->idKey, $ids, 'IN')
        ->execute();

      if (isset($this->revisionTable)) {
        db_delete($this->revisionTable)
          ->condition($this->idKey, $ids, 'IN')
          ->execute();
      }
      // Reset the cache as soon as the changes have been applied.
      $this->resetCache($ids);

      // Ignore slave server temporarily.
      db_ignore_slave();
    }
    catch (Exception $e) {
      $transaction->rollback();
      watchdog_exception($this->entityType, $e);
      throw $e;
    }
  }
}